@@ -15,8 +15,7 @@ class BlocoBinarioPosto(BlocoBinario):
 
     # Override
     def le(self, arq: BufferedReader):
-        """
-        """
+        """ """
         reg_nome = RegistroAnBinario(12)
         reg_ano = RegistroInBinario(32)
         nome = reg_nome.le_registro(arq)
@@ -25,8 +24,7 @@ class BlocoBinarioPosto(BlocoBinario):
 
     # Override
     def escreve(self, arq: BinaryIO):
-        """
-        """
+        """ """
         arq.write(self._dados[0].ljust(12).encode("ISO-8859-1"))
         anos = np.array(self._dados[1:]).astype("int32")
         anos.tofile(arq)
@@ -38,8 +36,8 @@ class LeituraPostos(LeituraBinario):
     Classe com utilidades gerais para leitura de arquivos
     do DECOMP com comentários.
     """
-    def __init__(self,
-                 diretorio: str):
+
+    def __init__(self, diretorio: str):
         super().__init__(diretorio)
 
     def _cria_blocos_leitura(self) -> List[BlocoBinario]:
@@ -49,7 +47,6 @@ class LeituraPostos(LeituraBinario):
         """
         MAX_BLOCOS = 600
 
-        b: List[BlocoBinario] = [BlocoBinarioPosto()
-                                 for _ in range(MAX_BLOCOS)]
+        b: List[BlocoBinario] = [BlocoBinarioPosto() for _ in range(MAX_BLOCOS)]
 
         return b
